-- Create_Real_Estate_Listing_Web_App.applescript
-- Create Real Estate Listing Web App

-- Created by Sal Soghoian on 8/13/10.
-- Copyright (c) MACOSXAUTOMATION.COM. 2010. All rights reserved.

script Create_Real_Estate_Listing_Web_App
	property parent : class "AMBundleAction"
	property log_status : true
	
	property state_province_abbreviations : {"AL", "AK", "AZ", "AR", "CA", "CO", "CT", "DE", "DC", "FL", "GA", "HI", "ID", "IL", "IN", "IA", "KS", "KY", "LA", "ME", "MD", "MA", "MI", "MN", "MS", "MO", "MT", "NE", "NV", "NH", "NJ", "NM", "NY", "NC", "ND", "OH", "OK", "OR", "PA", "RI", "SC", "SD", "TN", "TX", "UT", "VT", "VA", "WA", "WV", "WI", "WY", "AB", "BC", "MB", "NB", "NL", "NT", "NS", "NU", "ON", "PE", "QC", "SK", "YT"}
	property photoCount : 8
	
	property large_image_width : 1024
	property large_image_height : 768
	property headshot_image_width : 150
	property headshot_image_height : 200
	
	on runWithInput_fromAction_error_(input, anAction, errorRef)
		
		if log_status is true then
			log ("***************** BEGINNING NEW RUN *****************")
		end if
		
		#####################################################################################
		#						RETRIEVE AND LOG THE USER PARAMETER SETTINGS
		#####################################################################################
		
		-- GET PARAMETERS RECORD
		set parameters to my parameters()
		
		-- EXTRACT THE VARIOUS VALUES FOR THE INPUT PARAMETERS 
		set sortFilesAlphabetically to parameters's valueForKey_("sortFilesAlphabetically") as boolean
		set coverImagePath to parameters's valueForKey_("coverPhotoPath") as string
		set cropImagesToFit to parameters's valueForKey_("cropImagesToFit") as boolean
		
		if coverImagePath is "" then
			set useFirstImageAsCover to true
		else
			set useFirstImageAsCover to false
			try
				set coverImageFile to coverImagePath as POSIX file as alias
			on error -- problem locating the cover image file, then revert to using first image
				set useFirstImageAsCover to true
			end try
		end if
		
		if log_status is true then
			log ("sortFilesAlphabetically: " & sortFilesAlphabetically)
			log ("cropImagesToFit: " & cropImagesToFit)
			log ("coverImagePath: " & coverImagePath)
			log ("useFirstImageAsCover: " & useFirstImageAsCover)
		end if
		
		set listingStateIndex to parameters's valueForKey_("listingStateIndex") as integer
		set the listingState to item (listingStateIndex + 1) of state_province_abbreviations
		set listingCity to parameters's valueForKey_("listingCity") as string
		set listingDescription to parameters's valueForKey_("listingDescription") as string
		set listingHeadline to parameters's valueForKey_("listingHeadline") as string
		set listingMLS to parameters's valueForKey_("listingMLS") as string
		set listingPostalCode to parameters's valueForKey_("listingPostalCode") as string
		set listingStreet to parameters's valueForKey_("listingStreet") as string
		set listingPrice to parameters's valueForKey_("listingPrice") as string
		set listingPrice to my comma_delimit(listingPrice)
		
		if log_status is true then
			log ("listingStateIndex: " & listingStateIndex)
			log ("listingState: " & listingState)
			log ("listingCity: " & listingCity)
			log ("listingDescription: " & listingDescription)
			log ("listingHeadline: " & listingHeadline)
			log ("listingMLS: " & listingMLS)
			log ("listingPostalCode: " & listingPostalCode)
			log ("listingStreet: " & listingStreet)
			log ("listingPrice: " & listingPrice)
		end if
		
		set agencyName to parameters's valueForKey_("agencyName") as string
		set agentBio to parameters's valueForKey_("agentBio") as string
		set agentEmail to parameters's valueForKey_("agentEmail") as string
		set agentFirstName to parameters's valueForKey_("agentFirstName") as string
		set agentLastName to parameters's valueForKey_("agentLastName") as string
		set agentPhoneAreaCode to parameters's valueForKey_("agentPhoneAreaCode") as string
		set agentPhoneExchange to parameters's valueForKey_("agentPhoneExchange") as string
		set agentPhoneNumber to parameters's valueForKey_("agentPhoneNumber") as string
		set agentPhotoPath to parameters's valueForKey_("agentPhotoPath") as string
		set agentWebsite to parameters's valueForKey_("agentWebsite") as string
		if agentWebsite does not start with "http" then
			set agentWebsite to "http://" & agentWebsite
		end if
		
		if log_status is true then
			log ("agencyName: " & agencyName)
			log ("agentBio: " & agentBio)
			log ("agentEmail: " & agentEmail)
			log ("agentFirstName: " & agentFirstName)
			log ("agentLastName: " & agentLastName)
			log ("agentPhoneAreaCode: " & agentPhoneAreaCode)
			log ("agentPhoneExchange: " & agentPhoneExchange)
			log ("agentPhoneNumber: " & agentPhoneNumber)
			log ("agentPhotoPath: " & agentPhotoPath)
			log ("agentWebsite: " & agentWebsite)
		end if
		
		#####################################################################################
		#						CHECK AND FILTER INPUT
		#####################################################################################
		
		-- MAKE SURE INPUT IS A LIST
		set these_items to input as list -- get list of input items from the passed input
		
		-- FILTER THE INPUT ITEMS FOR IMAGES
		set the imageFilePaths to {}
		set the imageFileHFSAliases to {}
		repeat with i from 1 to the count of these_items
			set this_path to item i of these_items
			set the content_tree to (do shell script "mdls -name kMDItemContentTypeTree " & quoted form of this_path)
			if the content_tree contains "\"public.image\"" then
				set the end of the imageFilePaths to this_path
			end if
		end repeat
		if imageFilePaths is {} then
			error "No image files were provided as input for this action."
		end if
		if log_status is true then log ("imageFilePaths: " & imageFilePaths)
		
		if sortFilesAlphabetically is true then
			-- IMPORTANT: sorting assumes all passed files are in the same directory as the sort actually sorts the file paths NOT just the file names
			-- make list into array
			set anArray to current application's NSArray's arrayWithArray_(imageFilePaths)
			-- sort it
			set theList to anArray's sortedArrayUsingSelector_("localizedStandardCompare:") -- options are localizedCompare:,  caseInsensitiveCompare:
			-- convert back to AppleScript list
			set imageFilePaths to theList as list
			if log_status is true then log ("Sorted imageFilePaths: " & imageFilePaths)
		end if
		
		set the image_count to count of the imageFilePaths
		if log_status is true then
			log ("ACTION VARIABLE: image_count: " & image_count)
		end if
		
		-- get path and name of the first image file
		set the initialImagePath to (item 1 of the imageFilePaths)
		set the initialImageName to (do shell script "mdls -name kMDItemFSName " & quoted form of initialImagePath)
		
		-- generate HTML image loading code
		set the offsetTabs to tab & tab & tab
		repeat with i from 1 to the image_count
			if i is 1 then
				set the imageLoadingCode to offsetTabs & "var image1 = new Image();"
				set the imageLoadingCode to imageLoadingCode & linefeed & offsetTabs & "image1.onLoad = addToLoadList();"
				set the imageLoadingCode to imageLoadingCode & linefeed & offsetTabs & "image1.src = \"photos/1.jpg\";"
			else
				set the imageLoadingCode to imageLoadingCode & linefeed & offsetTabs & "var image" & (i as string) & " = new Image();"
				set the imageLoadingCode to imageLoadingCode & linefeed & offsetTabs & "image" & (i as string) & ".onLoad = addToLoadList();"
				set the imageLoadingCode to imageLoadingCode & linefeed & offsetTabs & "image" & (i as string) & ".src = \"photos/" & (i as string) & ".jpg\";"
			end if
		end repeat
		
		-- generate the hidden image links
		set the offsetTabs to tab & tab
		repeat with i from 1 to the image_count
			if i is 1 then
				set the imageLinkCode to offsetTabs & "<img src=\"photos/1.jpg\" width=\"1024\" height=\"768\" style=\"display:none;\" alt=\"\">"
			else
				set the imageLinkCode to imageLinkCode & linefeed & offsetTabs & "<img src=\"photos/" & (i as string) & ".jpg\" width=\"1024\" height=\"768\" style=\"display:none;\" alt=\"\">"
			end if
		end repeat
		
		#####################################################################################
		#						COPY THE TEMPLATE CONTENT TO A NEW FOLDER ON THE DESKTOP
		#####################################################################################
		
		-- GENERATE A UUID (UNIQUE IDENTIFIER)
		set targetUUID to (do shell script "uuidgen")
		
		-- CREATE THE DESTINATION FOLDER
		set the desktopFolderCompletePath to (do shell script "echo ~/Desktop/")
		set the targetFolderPath to desktopFolderCompletePath & targetUUID
		do shell script ("mkdir -m u=rwx,go=rwx " & targetFolderPath)
		delay 1
		set the targetFolderHFSPath to targetFolderPath as POSIX file as string
		if targetFolderHFSPath does not end with ":" then set targetFolderHFSPath to targetFolderHFSPath & ":"
		
		if log_status is true then log ("targetFolderHFSPath: " & targetFolderHFSPath)
		
		-- LOCATE THE TEMPLATE FILES IN THIS ACTION'S RESOURCE FOLDER
		set the templateFolderPath to (my |bundle|()'s pathForResource_ofType_("template", "")) as string
		
		if log_status is true then log ("templateFolderPath: " & templateFolderPath)
		
		-- DUPLICATE THE CONTENTS OF THE TEMPLATE FOLDER TO THE TARGET FOLDER
		-- add a forward slash to the end of the templateFolderPath so that the copy command copies the content of the template folder rather than the template folder itself 
		set the commandString to ("cp -R" & space & (the quoted form of (templateFolderPath & "/")) & space & (the quoted form of the targetFolderPath))
		if log_status is true then log ("commandString: " & commandString)
		do shell script commandString
		
		#####################################################################################
		#						EDIT THE NEW FILES REPLACING PLACEHOLDERS WITHIN THE FILES WITH USER SUPPLIED INFO
		#####################################################################################
		
		-- GENERATE REFERENCES TO KEY FILES AND LOCATIONS
		set the indexHTMLFile to targetFolderHFSPath & "index.html"
		set the viewsFolder to targetFolderHFSPath & "pages:"
		set the photosFolder to targetFolderHFSPath & "photos:"
		set the agentHTMLFile to viewsFolder & "agent.html"
		set the homeHTMLFile to viewsFolder & "home.html"
		set the mapHTMLFile to viewsFolder & "map.html"
		set the photosHTMLFile to viewsFolder & "photos.html"
		
		if log_status is true then log ("photosFolder: " & photosFolder)
		
		-- INDEX PAGE
		set the indexHTML to read (indexHTMLFile as alias) as «class utf8»
		
		set the indexHTML to my replace_chars(indexHTML, "IMAGECOUNTPLACEHOLDER", (image_count as string))
		set the indexHTML to my replace_chars(indexHTML, "IMAGELOADINGCODEPLACEHOLDER", imageLoadingCode)
		set the indexHTML to my replace_chars(indexHTML, "IMAGELINKCODEPLACEHOLDER", imageLinkCode)
		set the indexHTML to my replace_chars(indexHTML, "UUIDPLACEHOLDER", targetUUID)
		set the indexHTML to my replace_chars(indexHTML, "METADESCRIPTIONPLACEHOLDER", ("Real Estate listing for: " & listingStreet & ", " & listingCity & ", " & listingState & space & listingPostalCode))
		set the indexHTML to my replace_chars(indexHTML, "METAAUTHORPLACEHOLDER", (agentFirstName & space & agentLastName & ", " & agencyName))
		
		if my write_to_file(indexHTML, indexHTMLFile, false) is false then
			error "Problem writing the index file"
		end if
		
		-- AGENT INFO PAGE
		set the agentHTML to read (agentHTMLFile as alias) as «class utf8»
		
		set the agentHTML to my replace_chars(agentHTML, "AGENTNAMEPLACEHOLDER", (agentFirstName & space & agentLastName))
		set the agentHTML to my replace_chars(agentHTML, "AGENCYNAMEPLACEHOLDER", agencyName)
		set the agentHTML to my replace_chars(agentHTML, "AGENTPHONEPLACEHOLDER", (agentPhoneAreaCode & "-" & agentPhoneExchange & "-" & agentPhoneNumber))
		set the agentHTML to my replace_chars(agentHTML, "AGENTURLPLACEHOLDER", agentWebsite)
		set the agentHTML to my replace_chars(agentHTML, "AGENTBIOPLACEHOLDER", agentBio)
		set the agentHTML to my replace_chars(agentHTML, "AGENTEMAILPLACEHOLDER", agentEmail)
		set the agentHTML to my replace_chars(agentHTML, "PROPERTYMLSPLACEHOLDER", listingMLS)
		
		if my write_to_file(agentHTML, agentHTMLFile, false) is false then
			error "Problem writing the agent file"
		end if
		
		-- MAP PAGE
		set the mapHTML to read (mapHTMLFile as alias) as «class utf8»
		
		set propertyAddress to listingStreet & ", " & listingCity & ", " & listingState & space & listingPostalCode
		set encodedPropertyAddress to my encode_text(propertyAddress, true, true)
		set the mapHTML to my replace_chars(mapHTML, "PROPERTYADDRESSPLACEHOLDER", encodedPropertyAddress)
		
		if my write_to_file(mapHTML, mapHTMLFile, false) is false then
			error "Problem writing the map file"
		end if
		
		-- HOME PAGE
		set the homeHTML to read (homeHTMLFile as alias) as «class utf8»
		
		set the homeHTML to my replace_chars(homeHTML, "HEADLINEPLACEHOLDER", listingHeadline)
		set the homeHTML to my replace_chars(homeHTML, "AGENTNAMEPLACEHOLDER", (agentFirstName & space & agentLastName))
		set the homeHTML to my replace_chars(homeHTML, "AGENCYNAMEPLACEHOLDER", agencyName)
		set the homeHTML to my replace_chars(homeHTML, "PROPERTYADDRESSPLACEHOLDER", listingStreet)
		set the homeHTML to my replace_chars(homeHTML, "PROPERTYDESCRIPTIONPLACEHOLDER", listingDescription)
		set the homeHTML to my replace_chars(homeHTML, "PROPERTYPRICEPLACEHOLDER", listingPrice)
		set the homeHTML to my replace_chars(homeHTML, "AGENTPHONEPLACEHOLDER", (agentPhoneAreaCode & "-" & agentPhoneExchange & "-" & agentPhoneNumber))
		
		if my write_to_file(homeHTML, homeHTMLFile, false) is false then
			error "Problem writing the home file"
		end if
		
		-- PHOTOS PAGE
		set the photosHTML to read (photosHTMLFile as alias) as «class utf8»
		
		set the photosHTML to my replace_chars(photosHTML, "PHOTOCOUNTPLACEHOLDER", (image_count as string))
		
		if my write_to_file(photosHTML, photosHTMLFile, false) is false then
			error "Problem writing the photos file"
		end if
		
		#####################################################################################
		#						PROCESS THE IMAGE FILES
		#####################################################################################
		
		-- GENERATE THE SLIDESHOW IMAGES
		repeat with i from 1 to the image_count
			set thisImagePath to item i of the imageFilePaths
			log ("ACTION VARIABLE: thisImagePath: " & thisImagePath)
			if cropImagesToFit is false then
				my scaleAndPad(thisImagePath, large_image_width, large_image_height, (i as string), photosFolder, {13107, 13107, 13107}) -- same color as home underlay #333
			else
				my cropAndScale(thisImagePath, large_image_width, large_image_height, (i as string), photosFolder)
			end if
		end repeat
		if log_status is true then
			log ("ACTION STATUS: images generated")
		end if
		
		-- GENERATE THE AGENT PHOTO
		if agentPhotoPath is "" then
			if log_status is true then
				log ("ACTION STATUS: no agent photo provided, linking to default image")
			end if
			set the agentHTML to read (agentHTMLFile as alias) as «class utf8»
			set the agentHTML to my replace_chars(agentHTML, "../photos/agent.jpg", "../gfx/agent.jpg")
			if my write_to_file(agentHTML, agentHTMLFile, false) is false then
				error "Problem writing the agent file"
			end if
		else
			my cropAndScale(agentPhotoPath, headshot_image_width, headshot_image_height, "agent", photosFolder)
		end if
		
		-- GENERATE THE COVER PHOTO
		if useFirstImageAsCover is true then
			if log_status is true then
				log ("ACTION STATUS: using first image as cover")
			end if
			my cropAndScale(initialImagePath, large_image_width, large_image_height, "background", photosFolder)
		else
			if log_status is true then
				log ("ACTION STATUS: using chosen image as cover")
			end if
			my cropAndScale(coverImagePath, large_image_width, large_image_height, "background", photosFolder)
		end if
		
		#####################################################################################
		#						PASS THE PATH TO THE PATH TO THE CREATED DIRECTORY TO THE NEXT ACTION
		#####################################################################################
		
		if log_status is true then
			log ("ACTION STATUS: PROCESS COMPLETE. Passing directory reference: " & targetFolderPath)
		end if
		
		return targetFolderPath
		
	end runWithInput_fromAction_error_
	
	on comma_delimit(passed_value)
		set this_number to passed_value as string
		if this_number contains "E" then set this_number to (passed_value as inches as string)
		set the num_length to the length of this_number
		set the this_number to (the reverse of every character of this_number) as string
		set the delimited_number to ""
		repeat with i from 1 to the num_length
			if i is the num_length or (i mod 3) is not 0 then
				set the delimited_number to (character i of this_number & the delimited_number) as string
			else
				set the delimited_number to ("," & character i of this_number & the delimited_number) as string
			end if
		end repeat
		return the delimited_number
	end comma_delimit
	
	on write_to_file(this_data, target_file, append_data)
		tell application "System Events"
			try
				set the target_file to the target_file as string
				set the open_target_file to open for access file target_file with write permission
				if append_data is false then set eof of the open_target_file to 0
				write this_data to the open_target_file starting at eof as «class utf8»
				close access the open_target_file
				return true
			on error
				try
					close access file target_file
				end try
				return false
			end try
		end tell
	end write_to_file
	
	on replace_chars(this_text, search_string, replacement_string)
		set AppleScript's text item delimiters to the search_string
		set the item_list to every text item of this_text
		set AppleScript's text item delimiters to the replacement_string
		set this_text to the item_list as string
		set AppleScript's text item delimiters to ""
		return this_text
	end replace_chars
	
	-- this sub-routine is used to encode text 
	on encode_text(this_text, encode_URL_A, encode_URL_B)
		set the standard_characters to "abcdefghijklmnopqrstuvwxyz0123456789"
		set the URL_A_chars to "$+!'/?;&@=#%><{}[]\"~`^\\|*"
		set the URL_B_chars to ".-_:"
		set the acceptable_characters to the standard_characters
		if encode_URL_A is false then set the acceptable_characters to the acceptable_characters & the URL_A_chars
		if encode_URL_B is false then set the acceptable_characters to the acceptable_characters & the URL_B_chars
		set the encoded_text to ""
		repeat with this_char in this_text
			if this_char is in the acceptable_characters then
				set the encoded_text to (the encoded_text & this_char)
			else
				set the encoded_text to (the encoded_text & encode_char(this_char)) as string
			end if
		end repeat
		return the encoded_text
	end encode_text
	
	on encode_char(this_char)
		set the ASCII_num to (the ASCII number this_char)
		set the hex_list to {"0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "A", "B", "C", "D", "E", "F"}
		set x to item ((ASCII_num div 16) + 1) of the hex_list
		set y to item ((ASCII_num mod 16) + 1) of the hex_list
		return ("%" & x & y) as string
	end encode_char
	
	on scaleAndPad(this_image_file, target_width, target_height, target_name, target_photos_folder, pad_color)
		try
			set this_image_file to this_image_file as string
			if log_status is true then
				log ("ACTION STATUS: scale and pad: " & this_image_file)
			end if
			tell application "Image Events"
				-- start the Image Events application
				launch
				-- open the image file
				set this_image to open this_image_file
				-- get dimensions of the image
				copy dimensions of this_image to {source_width, source_height}
				-- calculate scaling
				if target_width is greater than target_height then -- target image is landscape
					if log_status is true then
						tell me to log ("ACTION STATUS: target image is landscape")
					end if
					if source_width is greater than the source_height then -- source image is landscape
						if log_status is true then
							tell me to log ("ACTION STATUS: source image is landscape")
						end if
						-- try scaling the source width to match the target width
						
						(* source_width/target_width = source_height/new_height *)
						(* CROSS MULTIPLY: (source_width * new_height) = (source_height * target_width) *)
						(* DIVIDE BY KNOWN VALUE: new_height = (source_height * target_width) / source_width *)
						
						set new_height to (source_height * target_width) / source_width
						if new_height is less than the target_height then
							-- the scaled image will fit in target dimensions, using the target width as the scale length
							set the scale_length to the target_width
						else
							-- scale the source height to match the target height
							
							(* source_height/target_height = source_width/new_width *)
							(* CROSS MULTIPLY: (source_height * new_width) = (source_width * target_height) *)
							(* DIVIDE BY KNOWN VALUE: new_width = (source_width * target_height) / source_height *)
							
							set new_width to (source_width * target_height) / source_height
							set the scale_length to the new_width
						end if
					else -- source image is portrait
						if log_status is true then
							tell me to log ("ACTION STATUS: source image is portrait")
						end if
						set the scale_length to target_height
					end if
				else if target_height is greater than target_width then -- target image is portrait
					if log_status is true then
						tell me to log ("ACTION STATUS: target image is portrait")
					end if
					if source_height is greater than the source_width then -- source image is portrait
						if log_status is true then
							tell me to log ("ACTION STATUS: source image is portrait")
						end if
						-- try scaling the source height to match the target height
						
						(* source_height/target_height = source_width/new_width *)
						(* CROSS MULTIPLY: (source_height * new_width) = (source_width * target_height) *)
						(* DIVIDE BY KNOWN VALUE: new_width = (source_width * target_height) / source_height *)
						
						set new_width to (source_width * target_height) / source_height
						-- check the new width to see if it fits
						if new_width is less than the target_width then
							-- the scaled image will fit in target dimensions, using the target height as the scale length
							set the scale_length to the target_height
						else
							-- scale the source width to match the target width
							(* source_width/target_width = source_height/new_height *)
							(* CROSS MULTIPLY: (source_width * new_height) = (source_height * target_width) *)
							(* DIVIDE BY KNOWN VALUE: new_height = (source_height * target_width) / source_width *)
							
							set new_height to (source_height * target_width) / source_width
							set the scale_length to the new_height
						end if
					else -- source image is landscape
						if log_status is true then
							tell me to log ("ACTION STATUS: source image is landscape")
						end if
						set the scale_length to target_width
					end if
				else -- square pad area
					set the scale_length to target_height
				end if
				if log_status is true then
					tell me to log ("ACTION STATUS: scaling image to: " & scale_length)
				end if
				-- perform action
				scale this_image to size scale_length
				if log_status is true then
					tell me to log ("ACTION STATUS: padding image to: " & target_width & " x " & target_height)
				end if
				-- perform action
				if pad_color is {0, 0, 0} then
					pad this_image to dimensions {target_width, target_height}
				else
					pad this_image to dimensions {target_width, target_height} with pad color pad_color
				end if
				-- save the changes
				save this_image as JPEG in ((target_photos_folder as string) & target_name & ".jpg") without icon
				-- purge the open image data
				close this_image
			end tell
			if log_status is true then
				tell me to log ("ACTION STATUS: image saved: " & ((target_photos_folder as string) & target_name & ".jpg"))
			end if
		on error error_message
			if log_status is true then
				log ("ACTION ERROR image edit: " & error_message)
			end if
		end try
	end scaleAndPad
	
	on cropAndScale(this_image_file, target_width, target_height, target_name, target_photos_folder)
		try
			set this_image_file to this_image_file as string
			if log_status is true then
				log ("ACTION STATUS: crop and scale: " & this_image_file)
			end if
			tell application "Image Events"
				-- start the Image Events application
				launch
				-- open the image file
				set this_image to open this_image_file
				-- get dimensions of the image
				copy dimensions of this_image to {source_width, source_height}
				-- calculate scaling
				if target_width is greater than target_height then -- target image is landscape
					if log_status is true then
						tell me to log ("ACTION STATUS: target image is landscape")
					end if
					if source_width is greater than the source_height then -- source image is landscape
						if log_status is true then
							tell me to log ("ACTION STATUS: source image is landscape")
						end if
						set crop_H to source_height
						set crop_W to source_height * (target_width / target_height)
						crop this_image to dimensions {crop_W, crop_H}
						save this_image as JPEG in ((target_photos_folder as string) & target_name & ".jpg") without icon
						close this_image
						set scale_dimension to target_width
					else -- source image is portrait 
						if log_status is true then
							tell me to log ("ACTION STATUS: source image is portrait")
						end if
						set scale_dimension to target_height
						save this_image as JPEG in ((target_photos_folder as string) & target_name & ".jpg") without icon
						close this_image
					end if
				else if target_height is greater than target_width then -- target image is portrait
					if log_status is true then
						tell me to log ("ACTION STATUS: target image is portrait")
					end if
					if source_height is greater than the source_width then -- source image is portrait
						if log_status is true then
							tell me to log ("ACTION STATUS: source image is portrait")
						end if
						set crop_H to source_height
						set crop_W to source_height * (target_width / target_height)
						crop this_image to dimensions {crop_W, crop_H}
						save this_image as JPEG in ((target_photos_folder as string) & target_name & ".jpg") without icon
						close this_image
						set scale_dimension to target_height
					else -- source image is landscape
						if log_status is true then
							tell me to log ("ACTION STATUS: source image is landscape")
						end if
						set crop_H to source_height
						set crop_W to source_height * (target_width / target_height)
						crop this_image to dimensions {crop_W, crop_H}
						save this_image as JPEG in ((target_photos_folder as string) & target_name & ".jpg") without icon
						close this_image
						set scale_dimension to target_height
					end if
				else -- square
					if log_status is true then
						tell me to log ("ACTION STATUS: source image is square")
					end if
					set scale_dimension to target_height
					save this_image as JPEG in ((target_photos_folder as string) & target_name & ".jpg") without icon
					close this_image
				end if
				-- re-open the image file
				set this_image to open ((target_photos_folder as string) & target_name & ".jpg")
				if log_status is true then
					tell me to log ("ACTION STATUS: scaling image to: " & scale_dimension)
				end if
				-- perform scale action
				scale this_image to size scale_dimension
				-- save the changes
				save this_image
				-- purge the open image data
				close this_image
			end tell
			if log_status is true then
				tell me to log ("ACTION STATUS: image saved: " & (target_photos_folder & target_name & ".jpg"))
			end if
		on error error_message
			if log_status is true then
				log ("ACTION ERROR image edit: " & error_message)
			end if
		end try
	end cropAndScale
	
	on create_manifest(source_folder)
		set source_folder_HFS_path to source_folder as string
		set the source_folder_path to POSIX path of the source_folder_HFS_path
		set the base_path_length to the length of the source_folder_path
		
		tell application "Finder"
			set the manifest_items to (every document file of the entire contents of folder source_folder_HFS_path)
			repeat with i from 1 to count of manifest_items
				set item i of manifest_items to (item i of manifest_items) as string
			end repeat
		end tell
		
		set new_line to character id 10
		set the manifest_text to "CACHE MANIFEST" & new_line & "webapp.manifest"
		
		repeat with i from 1 to count of manifest_items
			set this_item to item i of manifest_items
			set this_path to POSIX path of this_item
			set the relative_path to text from (base_path_length + 1) to -1 of this_path
			set the manifest_text to manifest_text & return & the relative_path
		end repeat
		
		set the manifest_text to manifest_text & new_line & new_line & "NETWORK:" & new_line & "http://web.me.com/"
		
		set the target_file to (source_folder as string) & "webapp.manifest"
		return my write_to_file(manifest_text, target_file, false)
	end create_manifest
	
	
	
end script


